# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/Users/noplay/code/gns3/gns3-gui/gns3/ui/edit_compute_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.8
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_EditComputeDialog(object):

    def setupUi(self, EditComputeDialog):
        EditComputeDialog.setObjectName("EditComputeDialog")
        EditComputeDialog.setWindowModality(QtCore.Qt.WindowModal)
        EditComputeDialog.resize(579, 374)
        self.verticalLayout = QtWidgets.QVBoxLayout(EditComputeDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(EditComputeDialog)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.uiServerNameLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.uiServerNameLineEdit.setObjectName("uiServerNameLineEdit")
        self.gridLayout.addWidget(self.uiServerNameLineEdit, 0, 1, 1, 1)
        self.uiServerPortSpinBox = QtWidgets.QSpinBox(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.uiServerPortSpinBox.sizePolicy().hasHeightForWidth())
        self.uiServerPortSpinBox.setSizePolicy(sizePolicy)
        self.uiServerPortSpinBox.setSuffix(" TCP")
        self.uiServerPortSpinBox.setMaximum(65535)
        self.uiServerPortSpinBox.setProperty("value", 3080)
        self.uiServerPortSpinBox.setObjectName("uiServerPortSpinBox")
        self.gridLayout.addWidget(self.uiServerPortSpinBox, 2, 1, 1, 2)
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.uiServerHostLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.uiServerHostLineEdit.setObjectName("uiServerHostLineEdit")
        self.gridLayout.addWidget(self.uiServerHostLineEdit, 1, 1, 1, 2)
        self.uiServerHostLabel = QtWidgets.QLabel(self.groupBox)
        self.uiServerHostLabel.setObjectName("uiServerHostLabel")
        self.gridLayout.addWidget(self.uiServerHostLabel, 1, 0, 1, 1)
        self.uiServerPortLabel = QtWidgets.QLabel(self.groupBox)
        self.uiServerPortLabel.setObjectName("uiServerPortLabel")
        self.gridLayout.addWidget(self.uiServerPortLabel, 2, 0, 1, 1)
        self.verticalLayout.addWidget(self.groupBox)
        self.uiEnableAuthenticationCheckBox = QtWidgets.QGroupBox(EditComputeDialog)
        self.uiEnableAuthenticationCheckBox.setCheckable(True)
        self.uiEnableAuthenticationCheckBox.setObjectName("uiEnableAuthenticationCheckBox")
        self.formLayout = QtWidgets.QFormLayout(self.uiEnableAuthenticationCheckBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.ExpandingFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.uiServerUserLabel = QtWidgets.QLabel(self.uiEnableAuthenticationCheckBox)
        self.uiServerUserLabel.setObjectName("uiServerUserLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.uiServerUserLabel)
        self.uiServerUserLineEdit = QtWidgets.QLineEdit(self.uiEnableAuthenticationCheckBox)
        self.uiServerUserLineEdit.setEnabled(True)
        self.uiServerUserLineEdit.setToolTip("")
        self.uiServerUserLineEdit.setObjectName("uiServerUserLineEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.uiServerUserLineEdit)
        self.uiServerPasswordLabel = QtWidgets.QLabel(self.uiEnableAuthenticationCheckBox)
        self.uiServerPasswordLabel.setObjectName("uiServerPasswordLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.uiServerPasswordLabel)
        self.uiServerPasswordLineEdit = QtWidgets.QLineEdit(self.uiEnableAuthenticationCheckBox)
        self.uiServerPasswordLineEdit.setEnabled(True)
        self.uiServerPasswordLineEdit.setInputMethodHints(QtCore.Qt.ImhHiddenText | QtCore.Qt.ImhNoAutoUppercase | QtCore.Qt.ImhNoPredictiveText | QtCore.Qt.ImhSensitiveData)
        self.uiServerPasswordLineEdit.setEchoMode(QtWidgets.QLineEdit.Password)
        self.uiServerPasswordLineEdit.setObjectName("uiServerPasswordLineEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.uiServerPasswordLineEdit)
        self.verticalLayout.addWidget(self.uiEnableAuthenticationCheckBox)
        self.uiWarningLabel = QtWidgets.QLabel(EditComputeDialog)
        self.uiWarningLabel.setWordWrap(True)
        self.uiWarningLabel.setObjectName("uiWarningLabel")
        self.verticalLayout.addWidget(self.uiWarningLabel)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        self.buttonBox = QtWidgets.QDialogButtonBox(EditComputeDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel | QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(EditComputeDialog)
        self.buttonBox.accepted.connect(EditComputeDialog.accept)
        self.buttonBox.rejected.connect(EditComputeDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(EditComputeDialog)
        EditComputeDialog.setTabOrder(self.uiServerNameLineEdit, self.uiServerHostLineEdit)
        EditComputeDialog.setTabOrder(self.uiServerHostLineEdit, self.uiServerPortSpinBox)
        EditComputeDialog.setTabOrder(self.uiServerPortSpinBox, self.uiEnableAuthenticationCheckBox)
        EditComputeDialog.setTabOrder(self.uiEnableAuthenticationCheckBox, self.uiServerUserLineEdit)
        EditComputeDialog.setTabOrder(self.uiServerUserLineEdit, self.uiServerPasswordLineEdit)

    def retranslateUi(self, EditComputeDialog):
        _translate = QtCore.QCoreApplication.translate
        EditComputeDialog.setWindowTitle(_translate("EditComputeDialog", "Edit server settings"))
        self.groupBox.setTitle(_translate("EditComputeDialog", "Server settings"))
        self.label.setText(_translate("EditComputeDialog", "Name:"))
        self.uiServerHostLineEdit.setText(_translate("EditComputeDialog", "192.168.56.101"))
        self.uiServerHostLabel.setText(_translate("EditComputeDialog", "Host:"))
        self.uiServerPortLabel.setText(_translate("EditComputeDialog", "Port:"))
        self.uiEnableAuthenticationCheckBox.setTitle(_translate("EditComputeDialog", "Enable authentication"))
        self.uiServerUserLabel.setText(_translate("EditComputeDialog", "User:"))
        self.uiServerPasswordLabel.setText(_translate("EditComputeDialog", "Password:"))
        self.uiWarningLabel.setText(_translate("EditComputeDialog", "<html><head/><body><p><span style=\" font-weight:600;\">WARNING</span>: Changing a server with authentication enabled will reset the password.</p></body></html>"))
